@@ -94,6 +94,10 @@ func (f *fakeMultiSubjectAccessReviewRegistry) Create(subjectAccessReview *autho
 	}
 }
 
+func (f *fakeMultiSubjectAccessReviewRegistry) CreateContext(ctx context.Context, sar *authorizationv1.SubjectAccessReview) (result *authorizationv1.SubjectAccessReview, err error) {
+	return f.Create(sar)
+}
+
 type fakeSubjectAccessReviewRegistry struct {
 	subjectAccessReviewRecord
 }
@@ -108,6 +112,10 @@ func (f *fakeSubjectAccessReviewRegistry) Create(subjectAccessReview *authorizat
 	}, f.err
 }
 
+func (f *fakeSubjectAccessReviewRegistry) CreateContext(ctx context.Context, sar *authorizationv1.SubjectAccessReview) (result *authorizationv1.SubjectAccessReview, err error) {
+	return f.Create(sar)
+}
+
 func TestPublicDockerImageRepository(t *testing.T) {
 	tests := map[string]struct {
 		stream         *imageapi.ImageStream
